@@ -305,8 +305,7 @@ def run_appbot(parser,args):
             )
 
     appbot.bot = AppBot()
-    appbot.bot.add_cog(appbot.RTFMCog(appbot.bot))
-    appbot.install()
+    appbot.install(appbot.export())
     appbot.run(task=args.task)
 
 def add_appbot_args(subparser):
