@@ -267,8 +267,9 @@ class RTFMCog(appcommands.Cog):
   ):
     await self.do_rtfm(ctx, f"python{version}", query,)
 
-def install():
+def install(bot: AppBot):
   if installed: return
+  global help_, uid, uid_, mid
 
   @bot.slashcommand(name="help", description="Get help of a command")
   async def help_(ctx, command: str = None):
@@ -281,13 +282,13 @@ def install():
       cmd=bot.get_slash_command(command)
       fmt=f"**`/{cmd.full_name}`**\n\n{cmd.description}"
       embed = discord.Embed(title="App Bot's Help Menu", description=fmt)
-      await ctx.send(embed=embed)
+    await ctx.send(embed=embed)
     
   @bot.usercommand(name="id")
   async def uid(ctx, user: discord.User):
     await ctx.send(f"Id of {user.mention} is `{user.id}`", ephemeral=True)
 
-  @bot.slashcommand(name="id", description="Get ID of a User",guild_ids=appcommands.ALL_GUILDS)
+  @bot.slashcommand(name="id", description="Get ID of a User")
   async def uid_(ctx, user: discord.User):
     await ctx.send(f"Id of {user.mention} is `{user.id}`", ephemeral=True)
 
@@ -299,8 +300,7 @@ def install():
 
   globals()["installed"] = True
 
-
-bot.add_cog(RTFMCog(bot))
+  globals()["bot"] = bot
 
 def export():
   return bot
@@ -310,6 +310,7 @@ def setup(func):
 
 def run(token: str = None, *, task: bool = False):
   try:
+    bot.add_cog(RTFMCog(bot))
     bot.load_extension("jishaku")
   except:
     pass
